# UCNDATA Examples and Tutorials

* [Installation](installation.md)
* [Getting Started](gettingstarted.md)
* [Contents of the ucnrun Object](ucnrun_contents.md)
* [Loading Runs](read.md)
* [Accessing Cycles and Periods](cycandperiods.md)
* [Filtering Cycles](filter.md)
* [Using ApplyLists](applylist.md)
* [Examples](examples.md)
* [Chopper module](chopper.md)
* [Filtering data events](filterdata.md)
* [Tips and FAQ](tips.md)
